/*
 *  Functions and Methods
 *
 *  Use Chrome Developer Tools to run and debug
 *  Add break point and reload page to inspect!
 */
// 'use strict';    // Just to show

// Function declaration -------------------------------------
function add(a, b) {
    return a + b;
}
var sum = add(1, 2); // Call (JS uses call by value)

// To many of few parameters
sum = add(1); // b undef -> Nan
sum = add(1, 2, 3); // Skip 3
console.log(typeof add);

// Hidden array-like variable
// "arguments" for all parameters
function argsTest() {
    for (var i = 0, j = arguments.length; i < j; i++) {
        console.log(arguments[i] + ' ');
    }
}
argsTest(1, 2, 3); // Params will end up in "arguments"

// Function declarations are hoisted,
// move to beginning of scope In this
// case the global scope (i.e. beginning
// of file) more later
console.log(mul(2, 3)); // Call before declaration, ok
function mul(a, b) {
    return a * b;
}

// Hoisting in functions -------------------------------------
// Variables moved to beginning of function
var a = 1;
function f() {
    console.log(a);
    var a = 2; // Declaration moved at activation, but NOT initialization!
}
f(); // Undef

// Function declaration vs expression -----------------------------

// console.log(mopp()); // Exception,
// function expression, not hoisted

var mopp = function() { // Function expression
    return 5;
};

console.log(mopp2()); // 5, OK
function mopp2() { // Function declaration hoisted
    return 5;
}
console.log(typeof mopp2);

// First class functions -------------------------------------
// Function as param
function param(f, a, b) {
    return f(a, b); // Apply function, COOL!
}
console.log(param(add, 1, 3));

// Function as return value
function getFunc() {
    return function(a) {
        return a * a;

    };
}
var o = getFunc(); // o is a function
console.log(o(5)); // Run it

// Nested functions declarations ------------------------------
function hypotenuse(a, b) {

    function square(x) { // Declaration inside other func!
        return x * x;
    }
    return Math.sqrt(square(a) + square(b));
}
//console.log(square(4)); // Not visible

// Methods. Function as a member of an object ---------------
var objectWithMethod = {
    val: 111, // These are property assignments
    doIt: function() {
        return this.val; // See this.js
    }
};
console.log(objectWithMethod.doIt());

// Immediately invoked function expression (IIFE ("iffy")) -----------

var x = 23;
(function(twice) { // Anything inside ( ... ) is an expression (else declaration)
    console.log(twice);
}(x * 2)); // <-------- (...) causes execution at once

var iffy = (function() {
    return 999;
})(); // <------ call at once
console.log(iffy);

/*
  Returning anonymous object with two methods.
  sayer is reference to the anonymous object returned
*/
var sayer = (function() {
    return {
        sayHello: function(a) {
            return "hello " + a;
        },
        sayGoodbye: function(a) {
            return "goodbye" + a;
        }
    };
})(); // <------ call at once
console.log(sayer.sayHello("Pelle"));

// Functions as objects (rarely needed) --------------------------
function fu() {
    fu.a = 6;
    fu.b = 9;
    fu.f = function() {
        return fu.a;
    };
};

fu(); // Must run once

fu.c = 13; // Add new property

console.log(fu.a);
console.log(fu.b);
console.log(fu.c);
console.log(fu.f());
