/*

  In-house server to demonstrate Mustache templating

  To run
  $ node app.js   (or $ nodemon)

  Visit localhost:8080

 NOTE: Much of this is handled automatically by the Express framework

*/
// Using nodes module system
var http = require('http');
var fs = require('fs');
var Mustache = require('mustache');

// Use node filesystem module.
var header = fs.readFileSync("partials/header.html", "utf-8");
var footer = fs.readFileSync("partials/footer.html", "utf-8");

// Emulating a model
var persons = [
    {
        id: 1,
        name: "pelle"
    }, {
        id: 2,
        name: "olle"
    }, {
        id: 3,
        name: "fia"
    }
];

// In-house server
http.createServer(function(request, response) {

    console.log(request.url);

    if (request.url.match(".css")) {
        fs.readFile("css/default.css", 'utf-8', function(error, source) {
            doResponse(response, source, "text/css");
        });
    } else if (request.url.match("index") || request.url === "/") {
        fs.readFile("index.html", 'utf-8', function(error, source) {
            doResponse(response, source, "text/html");
        });
    } else if (request.url.match("details")) {
        var id = request.url.split("=")[1].trim();
        fs.readFile('details.html', 'utf-8', function(error, source) {
            // Convert template to HTML (fill in dynaimic data)
            var html = Mustache.to_html(source, {
                person: persons[parseInt(id) - 1] // NOTE: parseInt
            }, {
                header: header,
                footer: footer
            });
            doResponse(response, html, "text/html");
        });
    } else {
        fs.readFile('master.html', 'utf-8', function(error, source) {
            // Convert template to HTML (fill in dynaimic data)
            var html = Mustache.to_html(source, {
                persons: persons
            }, {
                header: header,
                footer: footer
            });
            doResponse(response, html, "text/html");
        });
    };
}).listen(8080);

console.log("Server started at 8080");

// Utility
function doResponse(response, source, type) {
    response.writeHead(200, {
        'Content-Type': type,
        'Content-Length': source.length
    });
    response.write(source);
    response.end();
}
