package orm.model;

import java.io.Serializable;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.validation.constraints.Size;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;

/**
 * Simple mapping of one table
 *
 * NOTE: Mapping gets much more complex if using more tables and relationships
 * (1:1, 1:M, M:1, M:N)
 *
 * @author hajo
 */
@EqualsAndHashCode(of = "id")
@Entity
@Table(name = "Persons")
public class Person implements Serializable {

    private static final long serialVersionUID = 1L;
    @Getter
    @Setter
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    //@Basic(optional = false)
    @Column(name = "id", nullable = false, unique = true)
    private Long id;
    @Getter
    @Setter
    @Size(max = 20)
    @Column(name = "name")
    private String name;

    // MUST have
    public Person() {

    }

    public Person(String name) {
        this.name = name;
    }

    @Override
    public String toString() {
        return "Person{" + "id=" + id + ", name=" + name + "}";

    }

}
