/*

	Application entry (= main)
*/
var express = require('express');
var path = require('path');

var bodyParser = require('body-parser');
var index = require('./routes/index');
var list = require('./routes/list');

var app = express();

// CORS enable (if request from other domains)
// curl default uses same domain, see curl_tests.txt
app.all('/*', function(req, res, next) {
    res.header("Access-Control-Allow-Methods", "POST, GET, OPTIONS, PUT, DELETE");
    res.header("Access-Control-Allow-Origin", "*");
    res.header("Access-Control-Allow-Headers", "X-Requested-With, Content-Type");
    next();
});

app.get('/', function(req, res) {
    res.sendFile(path.join(__dirname + '/index.html'));
});

app.use(bodyParser.json());
app.use(bodyParser.urlencoded({extended: false}));

// The routes and routers
app.use('/', index);
app.use('/list', list);
// Catch 404 and forward to error handler
app.use(function(err, req, res, next) {
    //var err = new Error('Not Found');
    err.status = 404;
    next(err);
});
// Development error handler
// will print stacktrace
if (app.get('env') === 'development') {
    app.use(function(err, req, res, next) {
        res.status(err.status || 500);
        /*res.render('error', {
        	message: err.message,
        	error: err
        });*/
    });
}
// production error handler
// no stacktraces leaked to user
app.use(function(err, req, res, next) {
    res.status(err.status || 500);
    /*res.render('error', {
    	message: err.message,
    	error: {}
    });*/
});
app.listen(3000);
console.log("Listening to localhost:3000");

module.exports = app;
