/*
    The single (main) view for index.html
    Parent to personViews (but no explicit references between parent and children)
*/
define([
    'jquery', 'underscore', 'backbone', 'views/personView', 'models/person'
], function($, _, Backbone, PersonView, Person) {
    'use strict';

    var AppView = Backbone.View.extend({
        // The html element to attach to (this is a single view)
        el: "#personApp",

        // No template used for this (everything
        // in index.html)

        // Connect events and listeners (incomming from
        // GUI)
        events: {
            'keypress #newPerson': 'createOnEnter'
        },

        // Constructor
        initialize: function(personList) {
            this.personList = personList; // The collection reference

            // Cache some jQuery objects (efficency)
            this.$newPerson = this.$('#newPerson');
            this.$tbody = this.$('#personTable tbody');

            // Set this as observer of "add" events
            // in collection Call this.renderPerson
            // at event
            this.listenTo(this.personList, 'add', this.renderPerson);
            this.listenTo(this.personList, 'all', this.spy);
            this.render();
        },

        // Render list of persons
        render: function() {
            var self = this;
            // Must have reset true else duplicates.
            // Fetch will send add event, which will call renderPerson
            this.personList.fetch({reset: true}).done(function() {
                self.personList.each(function(person) {
                    self.renderPerson(person);
                });
            })
        },

        // GUI listener
        createOnEnter: function(e) {
            if (e.which !== 13 || !this.$newPerson.val().trim()) {
                return;
            }

            var name = this.$newPerson.val().trim();

            var attributes = {
                id: null,
                name: name
            };

            // Possibly Person.save(attributes)

            var self = this;
            // Will create instance, add to list and render
            this.personList.create(attributes, {
                // Skip wait to get an optimistic update (but then no id!!)
                // If so mar GUI (gray text or similar). Update on success
                wait: true, // Pessimistic, wait for server
                success: function(e) {
                    console.log("Created success" + JSON.stringify(e));
                },
                error: function(e) {
                    console.log("Created error " + JSON.stringify(e));
                }
            });

            // Clear GUI
            this.$newPerson.val('');
        },

        // Render single person
        renderPerson: function(person) {
            var view = new PersonView(person);
            view.render();
            // Append a row  (=view.el) to "#personTable body"
            this.$tbody.append(view.el);
        },
        // Utility
        spy: function(e) {
            console.log("appView spy " + e);
        }
    });

    return AppView;
});
