package jeecomp.control;

import jeecomp.viewmodel.PersonBB;
import jeecomp.core.Person;
import jeecomp.core.PersonRegistry;
import java.io.Serializable;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import javax.enterprise.context.RequestScoped;
import javax.inject.Inject;
import javax.inject.Named;

/**
 * Control bean (CDI bean)
 * @author hajo
 */
@Named("personctrl")  // Name in pages
@RequestScoped        // Short lived, save resources
public class PersonCtrl implements Serializable {

    private static final Logger LOG = Logger.getLogger(PersonCtrl.class.getSimpleName());
    private PersonRegistry registry;  // Model
    private PersonBB person;          // Model

    @PostConstruct
    public void post() {
        LOG.log(Level.INFO, "PersonCtrl alive {0}", this);
    }

    @PreDestroy
    public void pre() {
        LOG.log(Level.INFO, "PersonCtrl to be destroyed {0}", this);
    }

    @Inject
    public void setPersonRegistry(PersonRegistry registry) {
        this.registry = registry;
    }
    
    @Inject
    public void setPersonDetail(PersonBB person) {
        this.person = person;
    }
   
    // Execute business logic and navigate 
    public String save() {
        LOG.log(Level.INFO, "Save: '{'0'}'{0}", person);
        registry.add(new Person(person.getId(), person.getName()));
        return "list?faces-redirect=true";  // list is list.xhtml
    }
   
    public String update() {
        LOG.log(Level.INFO, "Update: '{'0'}'{0}", person);
        registry.update(new Person(person.getId(), person.getName()));
        return "list?faces-redirect=true"; 
    }

    public String delete() {
        LOG.log(Level.INFO, "Delete: '{'0'}'{0}", person);
        registry.delete(person.getId());
        return "list?faces-redirect=true";
    }
    
}
