package jeecomp.viewmodel;

import java.io.Serializable;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import javax.enterprise.context.RequestScoped;

import javax.inject.Named;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.Getter;
import lombok.Setter;

/**
 * Backing bean person data (i.e. hold page data), CDI bean
 *
 * @author hajo
 */
@Named("personbb")
@RequestScoped
public class PersonBB implements Serializable {

    private static final Logger LOG = Logger.getAnonymousLogger();

    @Getter
    @Setter
    @NotNull
    private Long id;
    
    @NotNull
    @Size(min = 1, max = 8, message = "Must use 1-8 chars")
    private String name;

    @PostConstruct
    public void post() {
        LOG.log(Level.INFO, "PersonBB alive {0}", this);
    }

    @PreDestroy
    public void pre() {
        LOG.log(Level.INFO, "PersonBB to be destroyed {0}", this);
    }

    @Override
    public String toString() {
        return "PersonBB{" + "id=" + id + ", fname=" + name + "}";
    }

    public String getName() {
        LOG.log(Level.INFO, "PersonBB getName {0}", this.name);
        return name;
    }

    public void setName(String name) {
        LOG.log(Level.INFO, "PersonBB setName {0}", name);
        this.name = name;
    }
    
    

}
